import { onMounted, ref } from 'vue'
import { defineStore } from 'pinia'
import { useRoute } from 'vue-router'
import { convertRouteToMenu } from '@/utils/route'
import { routes } from '@/router'
import type { MenuItemModel } from '@/utils/interfaces'

export const useMenuStore = defineStore('menu', () => {
    const route = useRoute()
    const navigation = ref<MenuItemModel[]>([])
    const sidebarOpen = ref(false)
    const sidebarShowed = ref(true)
    const menuSelected = ref(route.fullPath)
    const toggleSidebar = () => (sidebarOpen.value = !sidebarOpen.value)
    const toggleSidebarMenu = (path: string, newExpanded: boolean): void => {
        const toggleItemExpanded = (items: MenuItemModel[]): void => {
            for (const item of items) {
                if (item.path === path) {
                    item.expanded = newExpanded
                } else {
                    if (newExpanded) {
                        if (!path.includes(item.path)) {
                            item.expanded = !newExpanded;
                        }
                    }
                }
                if (item.children && item.children.length > 0) {
                    toggleItemExpanded(item.children)
                }
            }
        }

        toggleItemExpanded(navigation.value)
    }
    const toggleSidebarDesktop = () => (sidebarShowed.value = !sidebarShowed.value)

    onMounted(() => {
        const menuData = convertRouteToMenu(routes.at(0)?.children || [])
        navigation.value = menuData
    })

    return {
        navigation,
        toggleSidebar,
        sidebarOpen,
        menuSelected,
        toggleSidebarMenu,
        sidebarShowed,
        toggleSidebarDesktop
    }
})